class Interval(object):

    __list: list

    def __init__(self):
        # A constructor of Interval class which creates a new list.
        self.__list = []

    def add(self, start: int, end: int):
        """ The add method adds a new Tuple with given inputs to the list.

        Parameters
        ----------
        start : int
            first element of Tuple.
        end : int
            second element of Tuple.
        """
        self.__list.append((start, end))

    def getFirst(self, index: int) -> int:
        """ The getFirst method returns the first element at the list list's given index.

        Parameters
        ----------
        index : int
            to use at getting tuple from list.

        Returns
        ----------
        item
            the first element at the list list's given index.
        """
        return self.__list[index][0]

    def getLast(self, index: int) -> int:
        """ The getLast method returns the last element at the list list's given index.

        Parameters
        ----------
        index : int
            to use at getting tuple from list.

        Returns
        ----------
        item
            the last element at the list list's given index.
        """
        return self.__list[index][1]

    def size(self) -> int:
        """ The size method returns the size of the list list.
        Returns
        ----------
        int
            size of the list list.
        """
        return len(self.__list)



class Subset(object):

    set: list
    __rangeEnd: int
    elementCount: int

    def __init__(self, rangeStart: int, rangeEnd: int, elementCount: int):
        """
        The constructor of Subset class which takes 3 integer inputs; rangeStart, rangeEnd, and elementCount.
        It initializes variables rangeEnd and elementCount with given inputs, creates 2 arrays; set and multiset with
        the size of given elementCount and multisetCount, which is derived from elementCount, respectively. Then, it
        assigns rangeStart+i to each ith element of set.

        Parameters
        ----------
        rangeStart : int
            input defining start range.
        rangeEnd : int
            input defining ending range.
        elementCount : int
            input element count.
        """
        self.__rangeEnd = rangeEnd
        self.elementCount = elementCount
        self.set = []
        for i in range(elementCount):
            self.set.append(rangeStart + i)

    def get(self) -> list:
        """
        Getter for the set list

        Returns
        ----------
        list
            the set list
        """
        return self.set

    def next(self) -> bool:
        """
        The next method generates the next subset.

        Returns
        ----------
        boolean
            true if next subset generation is possible, false otherwise.
        """
        for i in range(self.elementCount - 1, -1, -1):
            self.set[i] = self.set[i] + 1
            if self.set[i] <= self.__rangeEnd - self.elementCount + i + 1:
                break
        else:
            return False
        for j in range(i + 1, self.elementCount):
            self.set[j] = self.set[j - 1] + 1
        return True

    def print(self):
        """
        The print method prints elements of set list.
        """
        for i in range(self.elementCount):
            print(self.set[i], end=" ")
        print()



from setuptools import setup

setup(
    name='NlpToolkit-Util',
    version='1.0.4',
    packages=['Util'],
    url='https://github.com/olcaytaner/Util-Py',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='Simple Utils'
)
